@@ -15,7 +15,7 @@ use Moo::Role;
 use POSIX qw/floor/;
 use Scalar::Util qw/looks_like_number/;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # for pitchnum (TODO make these attributes or otherwise f(x) calls?)
 my %NOTE2NUM = (
@@ -183,10 +183,13 @@ for example code.
 
 =head1 DESCRIPTION
 
-  "One need but glance at the various notations for a single tone
-  ... to be convinced that there is a sorrowful lack of agreement
-  in usage."
-    -- R. W. Young. "Terminology for Logarithmic Frequency Units"
+=over 4
+
+"One need but glance at the various notations for a single tone to be convinced
+that there is a sorrowful lack of agreement in usage." -- R. W. Young.
+"Terminology for Logarithmic Frequency Units"
+
+=back
 
 This module provides utility music pitch name and number routines; that is, an
 easy way to obtain pitch numbers from various pitch name formats (Helmholtz, or
@@ -301,7 +304,7 @@ L<http://www.dolmetsch.com/musictheory1.htm#helmholtz>
 =item *
 
 Young, R. W. (1939). "Terminology for Logarithmic Frequency Units". The Journal
-of the Acoustical Society of America 11 (1): 134–000.
+of the Acoustical Society of America 11 (1): 134-000.
 Bibcode:1939ASAJ...11..134Y. doi:10.1121/1.1916017.
 
 =item *
